==> kazehakase-0.4.6.tar.gz: kazehakase-0.4.6/module/embed/ie/kz-ie.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2007 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-gtk-webcore.h 3033 2007-03-26 23:31:29Z ikezoe $
 */

#ifndef __KZ_IE_H__
#define __KZ_IE_H__

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define KZ_TYPE_IE		(kz_ie_get_type ())
#define KZ_IE(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_IE, KzGtkWebcore))
#define KZ_IE_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_IE, KzIEClass))
#define KZ_IS_IE(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_IE))
#define KZ_IS_IE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_IE))
#define KZ_IE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_IE, KzIEClass))

typedef struct _KzIE		KzIE;
typedef struct _KzIEClass	KzIEClass;

struct _KzIE
{
	GtkWidget parent;
};

struct _KzIEClass
{
	GtkWidgetClass parent_class;
};


GType        kz_ie_get_type              (void) G_GNUC_CONST;
void         kz_ie_register_type         (GTypeModule *module);

G_END_DECLS

#endif /* __KZ_IE_H__ */

==> kazehakase-0.5.2.tar.gz: kazehakase-0.5.2/module/embed/ie/kz-ie.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2007 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-gtk-webcore.h 3033 2007-03-26 23:31:29Z ikezoe $
 */

#ifndef __KZ_IE_H__
#define __KZ_IE_H__

#include <gtk-ie-embed.h>

G_BEGIN_DECLS

#define KZ_TYPE_IE		(kz_ie_get_type ())
#define KZ_IE(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), KZ_TYPE_IE, KzGtkWebcore))
#define KZ_IE_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), KZ_TYPE_IE, KzIEClass))
#define KZ_IS_IE(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), KZ_TYPE_IE))
#define KZ_IS_IE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), KZ_TYPE_IE))
#define KZ_IE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), KZ_TYPE_IE, KzIEClass))

typedef struct _KzIE		KzIE;
typedef struct _KzIEClass	KzIEClass;

struct _KzIE
{
	GtkIEEmbed parent;
};

struct _KzIEClass
{
	GtkIEEmbedClass parent_class;
};


GType        kz_ie_get_type              (void) G_GNUC_CONST;
void         kz_ie_register_type         (GTypeModule *module);

G_END_DECLS

#endif /* __KZ_IE_H__ */
